
.. _tools:

******************
Command-line tools
******************

Overview
--------

.. autosummary::

    GooseHDF5.cli.G5check
    GooseHDF5.cli.G5list
    GooseHDF5.cli.G5print
    GooseHDF5.cli.G5repair
    GooseHDF5.cli.G5compare
    GooseHDF5.cli.G5repack

G5check
-------

.. automodule:: GooseHDF5.cli.G5check

G5list
------

.. automodule:: GooseHDF5.cli.G5list

G5print
-------

.. automodule:: GooseHDF5.cli.G5print

G5repair
--------

.. automodule:: GooseHDF5.cli.G5repair

G5compare
---------

.. automodule:: GooseHDF5.cli.G5compare

G5repack
--------

.. automodule:: GooseHDF5.cli.G5repack
